@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdcopyjob.cpp,v 1.61.2.6 2004/06/19 06:46:41 trueg Exp $
+ * $Id: k3bcdcopyjob.cpp,v 1.61.2.8 2004/11/28 00:22:29 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -656,7 +656,7 @@ bool K3bCdCopyJob::writeNextSession()
   emit newSubTask( i18n("Waiting for disk") );
 
   // if session > 1 we wait for an appendable CD
-  if( K3bEmptyDiscWaiter::wait( m_writerDevice, d->currentWrittenSession > 1 ) == K3bEmptyDiscWaiter::CANCELED ) {
+  if( K3bEmptyDiscWaiter::wait( m_writerDevice, d->currentWrittenSession > 1 && !m_simulate ) == K3bEmptyDiscWaiter::CANCELED ) {
     d->canceled = true;
     return false;
   }
@@ -824,10 +824,10 @@ bool K3bCdCopyJob::writeNextSession()
     bool multi = d->doNotCloseLastSession || (d->numSessions > 1 && d->currentWrittenSession < d->toc.count());
     int usedWritingMode = m_writingMode;
     if( usedWritingMode == K3b::WRITING_MODE_AUTO ) {
-      if( !m_writerDevice->dao() || d->toc.count() > 1 || multi )
-	usedWritingMode = K3b::TAO;
-      else
-	usedWritingMode = K3b::DAO;
+      // a lot of writers have problems to write pure Data CDs in DAO mode with cdrecord.
+      // So we simply always use TAO. I don't like it that much but maybe this will finally
+      // get rid of the bug reports...
+      usedWritingMode = K3b::TAO;
     }
     d->cdrecordWriter->setWritingMode( usedWritingMode );
 
