@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdimagewritingdialog.cpp,v 1.8 2004/01/21 10:20:12 trueg Exp $
+ * $Id: k3bcdimagewritingdialog.cpp,v 1.8.2.1 2004/07/04 10:41:53 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -27,7 +27,7 @@
 #include <k3bburnprogressdialog.h>
 #include <kcutlabel.h>
 #include <k3bstdguiitems.h>
-#include <tools/k3bmd5job.h>
+#include <k3bmd5job.h>
 #include <k3bdatamodewidget.h>
 #include <k3bglobals.h>
 #include <k3bwritingmodewidget.h>
