@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3b.cpp,v 1.192.2.2 2004/05/14 11:05:26 trueg Exp $
+ * $Id: k3b.cpp,v 1.192.2.3 2004/11/30 11:10:19 waba Exp $
  * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -1203,8 +1203,18 @@ void K3bMainWindow::slotProjectAddFiles()
   K3bDoc* doc = activeDoc();
 
   if( doc ) {
-    QStringList urls = KFileDialog::getOpenFileNames( ".", i18n("*|All Files"), this,
+    QStringList files = KFileDialog::getOpenFileNames( ".", i18n("*|All Files"), this,
                                                       i18n("Select Files to Add to Project") );
+
+    KURL::List urls;
+    for (QStringList::ConstIterator it = files.begin();
+         it != files.end(); it++)
+    {
+      KURL url;
+      url.setPath(*it);
+      urls.append( url );
+    }
+                                  
     if( !urls.isEmpty() )
       doc->addUrls( urls );
   }
