@@ -1,6 +1,6 @@
 /*
  *
- * $Id: main.cpp,v 1.73.2.15 2004/08/10 07:46:23 trueg Exp $
+ * $Id: main.cpp,v 1.73.2.21 2004/12/15 17:08:47 trueg Exp $
  *
  * This file is part of the K3b project.
  * Copyright (C) 1998-2004 Sebastian Trueg <trueg@k3b.org>
@@ -62,9 +62,9 @@ static KCmdLineOptions options[] =
 int main(int argc, char *argv[]) {
 
     KAboutData aboutData( "k3b", I18N_NOOP("K3b"),
-                          "0.11.14", description, KAboutData::License_GPL,
-                          I18N_NOOP("(c) 1999 - 2004, Sebastian Trueg and the K3b Team"), 0, "http://www.k3b.org" );
-    aboutData.addAuthor("Sebastian Trueg",I18N_NOOP("Maintainer"), "trueg@k3b.org");
+                          "0.11.19", description, KAboutData::License_GPL,
+                          I18N_NOOP("(c) 1999 - 2004, Sebastian Trüg and the K3b Team"), 0, "http://www.k3b.org" );
+    aboutData.addAuthor("Sebastian Trüg",I18N_NOOP("Maintainer"), "trueg@k3b.org");
     aboutData.addAuthor("Thomas Froescher",I18N_NOOP("Video-ripping and encoding"), "tfroescher@k3b.org");
     aboutData.addAuthor("Christian Kvasny",I18N_NOOP("VCD Project"), "chris@k3b.org");
     aboutData.addAuthor("Klaus-Dieter Krannich", I18N_NOOP("Developer"), "kd@k3b.org" );
