@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatajob.cpp,v 1.13 2004/01/25 16:06:57 trueg Exp $
+ * $Id: k3bdatajob.cpp,v 1.13.2.4 2004/11/23 19:39:48 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -583,9 +583,16 @@ void K3bDataJob::determineWritingMode()
 
 
   // determine the writing mode
+  // which is basicly to always use TAO since so many writers have problems to write Data CDs in DAO
+  // mode. Is there any drawback?
   if( d->doc->writingMode() == K3b::WRITING_MODE_AUTO ) {
-    if( d->doc->multiSessionMode() == K3bDataDoc::NONE &&
-	writer()->dao() )
+    // use DAO for overburned CDs
+    // TODO: put this into the cdreocrdwriter and decide based on the size of the
+    // track
+    k3bcore->config()->setGroup("General Options");
+    if( k3bcore->config()->readBoolEntry( "Allow overburning", false ) &&
+        writer()->dao() &&
+        d->doc->multiSessionMode() == K3bDataDoc::NONE )
       d->usedWritingMode = K3b::DAO;
     else
       d->usedWritingMode = K3b::TAO;
@@ -595,11 +602,12 @@ void K3bDataJob::determineWritingMode()
 
 
   // cdrecord seems to have problems writing xa 1 disks in dao mode? At least on my system!
+  // and many writers fail to write DAO with cdrecord. With this release we try cdrdao ;)
   if( writingApp() == K3b::DEFAULT ) {
     if( d->usedWritingMode == K3b::DAO ) {
-      if( d->doc->multiSessionMode() != K3bDataDoc::NONE )
+      if( k3bcore->externalBinManager()->binObject( "cdrdao" ) && d->doc->multiSessionMode() != K3bDataDoc::NONE )
 	d->usedWritingApp = K3b::CDRDAO;
-      else if( d->usedDataMode == K3b::MODE2 )
+      else if( k3bcore->externalBinManager()->binObject( "cdrdao" ) && d->usedDataMode == K3b::MODE2 )
 	d->usedWritingApp = K3b::CDRDAO;
       else
 	d->usedWritingApp = K3b::CDRECORD;
