@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdatavolumedescwidget.cpp,v 1.3.2.2 2004/07/21 10:04:57 trueg Exp $
+ * $Id: k3bdatavolumedescwidget.cpp,v 1.3.2.3 2005/01/12 18:27:05 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -44,10 +44,10 @@ K3bDataVolumeDescWidget::K3bDataVolumeDescWidget( QWidget* parent, const char* n
   // for now we hide the volume set stuff since it's not working anymore in mkisofs 2.01a34
   textLabel1->hide();
   textLabel2->hide();
-  TextLabel2->hide();
+//  TextLabel2->hide();
   m_spinVolumeSetSize->hide();
   m_spinVolumeSetNumber->hide();
-  m_editVolumeSetName->hide();
+  //  m_editVolumeSetName->hide();
 }
 
 
