@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3bdvdjob.cpp,v 1.21.2.5 2004/07/29 10:08:29 trueg Exp $
+ * $Id: k3bdvdjob.cpp,v 1.21.2.6 2005/01/12 18:27:05 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -396,7 +396,7 @@ void K3bDvdJob::slotVerificationFinished( bool success )
 
 void K3bDvdJob::cleanup()
 {
-  if( d->imageError || m_canceled || m_doc->removeImages() ) {
+  if( !m_doc->onTheFly() && ( d->imageError || m_canceled || m_doc->removeImages() ) ) {
     if( QFile::exists( m_doc->tempDir() ) ) {
       QFile::remove( m_doc->tempDir() );
       emit infoMessage( i18n("Removed image file %1").arg(m_doc->tempDir()), K3bJob::SUCCESS );
